@@ -1,10 +1,12 @@
 """Provide the Job class"""
+from __future__ import annotations
+
 import logging
 import shlex
 from os import PathLike
 from pathlib import Path
 import shutil
-from typing import TYPE_CHECKING, Any, Dict, Mapping, Union
+from typing import TYPE_CHECKING, Any, Dict, Mapping
 
 from diot import OrderedDiot
 from xqute import Job as XquteJob
@@ -33,7 +35,7 @@ class Job(XquteJob, JobCaching):
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         super().__init__(*args, **kwargs)
-        self.proc: "Proc" = None
+        self.proc: Proc = None
         self._output_types: Dict[str, str] = {}
         self._outdir = self.metadir / "output"
 
@@ -210,7 +212,7 @@ class Job(XquteJob, JobCaching):
 
     def log(
         self,
-        level: Union[int, str],
+        level: int | str,
         msg: str,
         *args,
         limit: int = 3,
@@ -242,7 +244,7 @@ class Job(XquteJob, JobCaching):
 
         self.proc.log(level, job_index_indicator + msg, *args, logger=logger)
 
-    async def prepare(self, proc: "Proc") -> None:
+    async def prepare(self, proc: Proc) -> None:
         """Prepare the job by given process
 
         Primarily prepare the script, and provide cmd to the job for xqute
